<template>
    <div>
        <v-dialog v-model="dialog" max-width="800px" persistent>
            <v-card>
                <v-card-title class="text-h5">
                    Charger le fichier multimédia
                </v-card-title>
                <v-card-text>
                    <v-form v-model="valid">
                        <v-container>
                            <v-file-input v-model="files"
                                          accept="image/*,video/*,audio/*,.pdf,.doc,.docx,application/msword,application/vnd.openxmlformats-officedocument.wordprocessingml.document"
                                          chips counter label="Click to choose one or more files" multiple
                                          show-size small-chips truncate-length="12"
                                          @change="fileChange"></v-file-input>
                            <v-text-field v-show="files.length === 1" v-model="label" counter label="Label"
                                          maxlength="25"></v-text-field>
                            <v-textarea v-show="files.length === 1" v-model="description" label="Description"
                                        outlined></v-textarea>
                        </v-container>
                    </v-form>
                    <v-divider/>
                    <v-item-group v-model="selected" active-class="green">
                        <v-container>
                            <v-row>
                                <v-col v-for="(file, index) in files" :key="index" cols="12" lg="2" md="2" sm="3"
                                       xs="4">
                                    <v-item v-slot="{ active, toggle }">
                                        <v-img v-if="file.type.startsWith('image')" :lazy-src="createObject(file)"
                                               :src="createObject(file)"
                                               aspect-ratio="1" class="grey lighten-2 text-right" max-width="180"
                                               @click="toggle">
                                            <v-scroll-y-transition>
                                                <div v-if="active" class="text-h5 flex-grow-1">
                                                    <v-icon color="green" large>mdi-check-decagram</v-icon>
                                                </div>
                                            </v-scroll-y-transition>
                                            <template v-slot:placeholder>
                                                <v-row align="center" class="fill-height ma-0" justify="center">
                                                    <v-progress-circular color="grey lighten-5"
                                                                         indeterminate></v-progress-circular>
                                                </v-row>
                                            </template>
                                        </v-img>
                                        <video v-else-if="file.type.startsWith('video')" :src="createObject(file)"
                                               width="180" @click.native="toggle">
                                            <v-scroll-y-transition>
                                                <div v-if="active" class="text-h5 flex-grow-1">
                                                    <v-icon color="green" large>mdi-check-decagram</v-icon>
                                                </div>
                                            </v-scroll-y-transition>
                                        </video>
                                        <!--<pdf v-else-if="file.type.startsWith('application/pdf')" :src="createObject(file)" @click.native="toggle">
                                                <v-scroll-y-transition>
                                                    <div v-if="active" class="text-h5 flex-grow-1">
                                                        <v-icon large color="green">mdi-check-decagram</v-icon>
                                                    </div>
                                                </v-scroll-y-transition>
                                            </pdf>-->
                                        <span v-else></span>
                                    </v-item>
                                </v-col>
                            </v-row>
                        </v-container>
                    </v-item-group>
                </v-card-text>
                <v-card-actions>
                    <v-btn color="error darken-1" text @click="dialog = false">
                        Fermer
                    </v-btn>
                    <v-spacer/>
                    <v-btn :loading="loading" color="green darken-1" dark @click="upload">
                        Importer &nbsp;<span v-if="selected >= 0"> et Sélectionner</span>
                        <v-icon right>mdi-cloud-upload-outline</v-icon>
                    </v-btn>
                </v-card-actions>
            </v-card>
        </v-dialog>
    </div>
</template>

<script>
// import pdf from 'vue-pdf'
export default {
    name: "AddMediaDialog",
    props: {
        display: {
            type: Boolean,
            required: true
        }
    },
    // components: {pdf},
    data() {
        return {
            dialog: false,
            valid: false,
            files: [],
            selected: null,
            label: '',
            description: '',
            loading: false,
        }
    },
    watch: {
        display(value) {
            this.dialog = value
        },
        dialog(value) {
            if (value === false) {
                this.$emit('state-changed', value)
            }
        }
    },
    methods: {
        fileChange(files) {
            if (files.length === 1) {
                this.selected = 0
                this.label = files[0].name.replace(/\.[^/.]+$/, "")
            }
        },
        createObject(file) {
            return URL.createObjectURL(file)
        },
        upload() {
            this.loading = true
            let formData = new FormData()
            this.files.forEach(function (file) {
                formData.append(`files[]`, file)
            })
            formData.append('label', this.label)
            formData.append('description', this.description)
            axios.post(this.$route('media.store', this.$route().params), formData)
                .then(res => {
                    this.$emit('upload-complete', res.data.data)
                    // this.$toast.success('Téléchargement réussi.')
                    if (res.data.data.length) {
                        let toEmit = null
                        if (this.selected >= 0 && ((res.data.data.length - 1) >= this.selected)) {
                            toEmit = res.data.data[this.selected]
                        }
                        this.files = []
                        this.dialog = false
                    }
                })
                .catch(err => console.log('Erreur rencontrée lors du téléchargement de fichier(s). ' + err.response))
                .then(() => (this.loading = !this.loading))
        }
    }
}
</script>

<style scoped>

</style>
